# ETP v1.2 messages and objects

This section documents the implemented protocols and data types from ETP v1.2.
We aim to support the same subset of ETP v1.2 as the OSDU
[open-etp-server](https://community.opengroup.org/osdu/platform/domain-data-mgmt-services/reservoir/open-etp-server).
Documentation for ETP v1.2 is found here:
[https://publications.opengroup.org/standards/energistics-standards/energistics-transfer-protocol/v234](https://publications.opengroup.org/standards/energistics-standards/energistics-transfer-protocol/v234).



## Protocol 0: Core

::: energistics.etp.v12.protocol.core

## Protocol 3: Discovery

::: energistics.etp.v12.protocol.discovery

## Protocol 4: Store

::: energistics.etp.v12.protocol.store

## Protocol 9: DataArray

::: energistics.etp.v12.protocol.data_array

## Protocol 18: Transaction

::: energistics.etp.v12.protocol.transaction

## Protocol 24: Dataspace

::: energistics.etp.v12.protocol.dataspace

## ETP Datatypes

::: energistics.etp.v12.datatypes

### Data array types

::: energistics.etp.v12.datatypes.data_array_types

### Object

::: energistics.etp.v12.datatypes.object
